<?php
class NotExistsValidator extends CValidator
{
	/**
	 * @var string path
	 * File path to search for existance. 
	 *
	 * WARNING:
	 *			Trailing slash must be included
	 *
	 * Ex:	path='protected/uploads/'
	 **/
	public $path;
	/**
	 * @var boolean renameIfExists
	 * wheter to rename the attribute if exists
	 * default to false
	 **/
	public $renameIfExists=false;
	/**
	 * @var string message to be shown when an error occurs
	 **/
	public $message='{attribute} {value} already exists';
	/**
	 * @var string _extension
	 * holds the extension ex .php
	 * used to rename attribute with extension when renameAttribute is enabled
	 **/
	private $_extension;
	
	protected function validateAttribute($object,$attribute)
	{
		//value of attribute
		$value=$object->$attribute;
		/**
		 *	if file exists checks whether renameAttribute is enabled
		 *  if renameAttribute is enabled it rename the attribute with random value , @var _extension and calls this function recursively
		 *  else displays error message
		 **/
		if(file_exists($this->path.$object->$attribute))
			if(!$this->renameIfExists)
			$this->addError($object,$attribute,$this->message,array('{value}'=>CHtml::encode($value)));
			else{
					//get the extension concatenated with dot ( . )
					$this->_extension='.'.CFileHelper::getExtension($this->path.$value);
					$object->$attribute=rand().$this->_extension;
					$this->validateAttribute($object,$attribute);
				}
	}
}
	